breezedb Package
================

:mod:`db` Module
----------------

.. automodule:: db
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`element` Module
---------------------

.. automodule:: element
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`field` Module
-------------------

.. automodule:: field
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`table` Module
-------------------

.. automodule:: table
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`breeze_exceptions` Module
-------------------------------

.. automodule:: breeze_exceptions
    :members:
    :undoc-members:
    :show-inheritance:

